PoissonZellnerPrior(
predictors,
counts = NULL,
exposure = NULL,
prior.event.rate = NULL,
expected.model.size = 1,
prior.information.weight = .01,
diagonal.shrinkage = .5,
optional.coefficient.estimate = NULL,
max.flips = -1,
prior.inclusion.probabilities = NULL)NULL if
prior.event.rate is specified.counts, giving
the "exposure time" for each observation. This can also be
NULL, signifying that exposure = 1.0 for each
observation.optional.coefficient.estimate is NULL) and to weight
the information matrix in the "slab" portion of the prioncol(x), representing a guess at
the number of significant predictor variables. Used to obtain the
'spike' portion of the spike and slab prior.NULL then a
default set of probabilities is obtained by setting each element
equal to min(1, expected.model.size / ncol(x)).PoissonZellnerPrior, which is a list
with data elements encoding the selected prior values. It inherits
from PoissonPrior and from SpikeSlabGlmPrior, which
implies that it contains an element prior.success.probability. This object is intended for use with poisson.spike.
$$\beta | \gamma \sim N(b, V)$$ $$\gamma \sim B(\pi)$$
where $\pi$ is the vector of
prior.inclusion.probabilities, and $b$ is the
optional.coefficient.estimate. Conditional on
$\gamma$, the prior information matrix is
$$V^{-1} = \kappa ((1 - \alpha) x^Twx / n + \alpha diag(x^Twx / n))$$
The matrix $x^Twx$ is, for suitable choice of the weight vector $w$, the total Fisher information available in the data. Dividing by $n$ gives the average Fisher information in a single observation, multiplying by $\kappa$ then results in $\kappa$ units of "average" information. This matrix is averaged with its diagonal to ensure positive definiteness.
In the formula above, $\kappa$ is
prior.information.weight, $\alpha$ is
diagonal.shrinkage, and $w$ is a diagonal matrix with all
elements set to prior.success.probability * (1 -
prior.success.probability). The vector $b$ and the matrix
$V^{-1}$ are both implicitly subscripted by $\gamma$,
meaning that elements, rows, or columsn corresponding to gamma = 0
should be omitted.