Learn R Programming

BoomSpikeSlab (version 0.4.1)

print.summary.lm.spike: Print method for spikeslab objects.

Description

Print a spikeslab object.

Usage

## S3 method for class 'summary.lm.spike':
print(x, ...)
## S3 method for class 'summary.logit.spike':
print(x, ...)

Arguments

x
An object of class summary.lm.spike.
...
Additional arguments passed to print.default.

Value

  • This function is called for its side effect, which is to print the spikeslab object to the screen.

See Also

lm.spike summary.lm.spike

Examples

Run this code
n <- 100
  p <- 10
  ngood <- 3
  niter <- 1000
  sigma <- 2

  x <- cbind(1, matrix(rnorm(n * (p-1)), nrow=n))
  beta <- c(rnorm(ngood), rep(0, p - ngood))
  y <- rnorm(n, x %*% beta, sigma)
  x <- x[,-1]
  model <- lm.spike(y ~ x, niter=niter)
  summary(model)

Run the code above in your browser using DataLab