Learn R Programming

BoomSpikeSlab (version 0.5.3)

student.spike.slab.prior: Spike and Slab Prior for Student-T Regression

Description

A Zellner-style spike and slab prior for regression models with Student-t errors.

Usage

StudentSpikeSlabPrior(predictor.matrix,
    response.vector = NULL,
    expected.r2 = .5,
    prior.df = .01,
    expected.model.size = 1,
    prior.information.weight = .01,
    diagonal.shrinkage = .5,
    optional.coefficient.estimate = NULL,
    max.flips = -1,
    mean.y = mean(response.vector, na.rm = TRUE),
    sdy = sd(as.numeric(response.vector), na.rm = TRUE),
    prior.inclusion.probabilities = NULL,
    sigma.upper.limit = Inf,
    degrees.of.freedom.prior = UniformPrior(.1, 100))

Arguments

predictor.matrix
The design matrix for the regression problem. Missing data is not allowed.
response.vector
The vector of responses for the regression. Missing data is not allowed. If response.vector is not available, you can pass response.vector = NULL, and specify mean.y and sdy instead.
expected.r2
The expected R-square for the regression. The spike and slab prior requires an inverse gamma prior on the residual variance of the regression. The prior can be parameterized in terms of a guess at the residual variance, and a "degrees of fre
prior.df
A positive scalar representing the prior 'degrees of freedom' for estimating the residual variance. This can be thought of as the amount of weight (expressed as an observation count) given to the expected.r2 argument.
expected.model.size
A positive number less than ncol(x), representing a guess at the number of significant predictor variables. Used to obtain the 'spike' portion of the spike and slab prior.
prior.information.weight
A positive scalar. Number of observations worth of weight that should be given to the prior estimate of beta.
diagonal.shrinkage
The conditionally Gaussian prior for beta (the "slab") starts with a precision matrix equal to the information in a single observation. However, this matrix might not be full rank. The matrix can be made full rank by averaging with its diagon
optional.coefficient.estimate
If desired, an estimate of the regression coefficients can be supplied. In most cases this will be a difficult parameter to specify. If omitted then a prior mean of zero will be used for all coordinates except the intercept, which will b
max.flips
The maximum number of variable inclusion indicators the sampler will attempt to sample each iteration. If max.flips <= 0<="" code=""> then all indicators will be sampled.
mean.y
The mean of the response vector, for use in cases when specifying the response vector is undesirable.
sdy
The standard deviation of the response vector, for use in cases when specifying the response vector is undesirable.
prior.inclusion.probabilities
A vector giving the prior probability of inclusion for each variable.
sigma.upper.limit
The largest acceptable value for the residual standard deviation. A non-positive number is interpreted as Inf.
degrees.of.freedom.prior
An object of class DoubleModel representing the prior distribution for the Student T tail thickness (or "degrees of freedom") parameter.

Value

References

George and McCulloch (1997), "Approaches to Bayesian Variable Selection", Statistica Sinica, 7, 339 -- 373.

http://www3.stat.sinica.edu.tw/statistica/oldpdf/A7n26.pdf