Learn R Programming

BoomSpikeSlab (version 0.5.2)

summary.lm.spike: Numerical summaries of the results from a spike and slab regression.

Description

Produces a summary of the marginal distribution of model coefficients from a spike and slab regression.

Usage

## S3 method for class 'lm.spike':
summary(object, burn = 0, order = TRUE, ...)

Arguments

object
An object of class lm.spike.
burn
The number of MCMC iterations in the ojbect to be discarded as burn-in.
order
Logical. If TRUE then the coefficients are presented in order of their posterior inclusion probabilities. Otherwise the order of the coefficients is the same as in object.
...
Unused. Present for compatibility with generic summary().

Value

  • Returns a list with the following elements:
  • coefficientsA five-column matrix with rows representing model coefficients. The first two columns are the posterior mean and standard deviation of each coefficient, including the point mass at zero. The next two columns are the posterior mean and standard deviations conditional on the coefficient being nonzero. The last column is the probability of a nonzero coefficient.
  • residual.sdA summary of the posterior distribution of the residual standard deviation parameter.
  • rsquareA summary of the posterior distribution of the R^2 statistic: 1 - residual.sd^2 / var(y)

See Also

lm.spike SpikeSlabPrior plot.lm.spike predict.lm.spike

Examples

Run this code
n <- 100
  p <- 10
  ngood <- 3
  niter <- 1000
  sigma <- 2

  x <- cbind(1, matrix(rnorm(n * (p-1)), nrow=n))
  beta <- c(rnorm(ngood), rep(0, p - ngood))
  y <- rnorm(n, x %*% beta, sigma)
  x <- x[,-1]
  model <- lm.spike(y ~ x, niter=niter)
  plot(model)
  plot.ts(model$beta)
  hist(model$sigma)  ## should be near 8
  summary(model)

Run the code above in your browser using DataLab